@@ -3,7 +3,7 @@ use std::{
     sync::{Mutex, MutexGuard},
 };
 
-use crate::wchar::prelude::*;
+use crate::prelude::*;
 use once_cell::sync::Lazy;
 
 use crate::parse_constants::SourceRange;
@@ -114,7 +114,7 @@ impl Abbreviation {
 
     // Return if we expand in a given position.
     fn matches_position(&self, position: Position) -> bool {
-        return self.position == Position::Anywhere || self.position == position;
+        self.position == Position::Anywhere || self.position == position
     }
 }
 
@@ -194,7 +194,7 @@ impl AbbreviationSet {
                 });
             }
         }
-        return result;
+        result
     }
 
     /// Return whether we would have at least one replacer for a given token.
@@ -287,9 +287,9 @@ mod tests {
     use super::{Abbreviation, Position, abbrs_get_set, abbrs_match, with_abbrs_mut};
     use crate::editable_line::{Edit, apply_edit};
     use crate::highlight::HighlightSpec;
+    use crate::prelude::*;
     use crate::reader::reader_expand_abbreviation_at_cursor;
     use crate::tests::prelude::*;
-    use crate::wchar::prelude::*;
 
     #[test]
     #[serial]
