@@ -4,7 +4,7 @@ use std::num::NonZeroUsize;
 
 use super::*;
 use crate::env::{EnvMode, EnvVar, EnvVarFlags};
-use crate::flog::FLOG;
+use crate::flog::flog;
 use crate::parse_util::parse_util_unescape_wildcards;
 use crate::wildcard::{ANY_STRING, wildcard_match};
 
@@ -64,7 +64,7 @@ impl<'args> StringSubCommand<'args> for Match<'args> {
             }
             _ => return Err(StringError::UnknownOption),
         }
-        return Ok(());
+        Ok(())
     }
 
     fn take_args(
@@ -93,7 +93,7 @@ impl<'args> StringSubCommand<'args> for Match<'args> {
         let cmd = args[0];
 
         if self.entire && self.index {
-            streams.err.append(wgettext_fmt!(
+            streams.err.append(&wgettext_fmt!(
                 BUILTIN_ERR_COMBO2,
                 cmd,
                 wgettext!("--entire and --index are mutually exclusive")
@@ -102,7 +102,7 @@ impl<'args> StringSubCommand<'args> for Match<'args> {
         }
 
         if self.invert_match && self.groups_only {
-            streams.err.append(wgettext_fmt!(
+            streams.err.append(&wgettext_fmt!(
                 BUILTIN_ERR_COMBO2,
                 cmd,
                 wgettext!("--invert and --groups-only are mutually exclusive")
@@ -111,7 +111,7 @@ impl<'args> StringSubCommand<'args> for Match<'args> {
         }
 
         if self.entire && self.groups_only {
-            streams.err.append(wgettext_fmt!(
+            streams.err.append(&wgettext_fmt!(
                 BUILTIN_ERR_COMBO2,
                 cmd,
                 wgettext!("--entire and --groups-only are mutually exclusive")
@@ -127,9 +127,9 @@ impl<'args> StringSubCommand<'args> for Match<'args> {
             }
         };
 
-        for (arg, _) in arguments(args, optind, streams) {
+        for InputValue { arg, .. } in arguments(args, optind, streams) {
             if let Err(e) = matcher.report_matches(arg.as_ref(), streams) {
-                FLOG!(error, "pcre2_match unexpected error:", e.error_message())
+                flog!(error, "pcre2_match unexpected error:", e.error_message())
             }
             let match_count = matcher.match_count();
             if self.quiet && match_count > 0
@@ -188,7 +188,7 @@ impl<'opts, 'args> StringMatcher<'opts, 'args> {
             Ok(Self::Regex(m))
         } else {
             let m = WildCardMatcher::new(pattern, opts);
-            return Ok(Self::WildCard(m));
+            Ok(Self::WildCard(m))
         }
     }
 
@@ -243,7 +243,7 @@ impl<'opts, 'args> RegexMatcher<'opts, 'args> {
             first_match_captures,
             opts,
         };
-        return Ok(m);
+        Ok(m)
     }
 
     fn report_matches(&mut self, arg: &wstr, streams: &mut IoStreams) -> Result<(), pcre2::Error> {
@@ -312,7 +312,7 @@ impl<'opts, 'args> RegexMatcher<'opts, 'args> {
                 return Err(RegexError::InvalidCaptureGroupName(wname));
             }
         }
-        return Ok(());
+        Ok(())
     }
 
     fn report_match<'a>(
@@ -324,7 +324,7 @@ impl<'opts, 'args> RegexMatcher<'opts, 'args> {
         let Some(cg) = cg else {
             if self.opts.invert_match && !self.opts.quiet {
                 if self.opts.index {
-                    streams.out.append(sprintf!("1 %u\n", arg.len()));
+                    streams.out.append(&sprintf!("1 %u\n", arg.len()));
                 } else {
                     streams.out.appendln(arg);
                 }
@@ -353,13 +353,13 @@ impl<'opts, 'args> RegexMatcher<'opts, 'args> {
             if self.opts.index {
                 streams
                     .out
-                    .append(sprintf!("%u %u\n", m.start() + 1, m.end() - m.start()));
+                    .append(&sprintf!("%u %u\n", m.start() + 1, m.end() - m.start()));
             } else {
                 streams.out.appendln(&arg[m.start()..m.end()]);
             }
         }
 
-        return MatchResult::Match(Some(cg));
+        MatchResult::Match(Some(cg))
     }
 }
 
@@ -401,7 +401,7 @@ impl<'opts, 'args> WildCardMatcher<'opts, 'args> {
             self.total_matched += 1;
             if !self.opts.quiet {
                 if self.opts.index {
-                    streams.out.append(sprintf!("1 %u\n", arg.len()));
+                    streams.out.append(&sprintf!("1 %u\n", arg.len()));
                 } else {
                     streams.out.appendln(arg);
                 }
@@ -486,7 +486,7 @@ mod tests {
     #[serial]
     #[rustfmt::skip]
     fn test_qmark_noglob_true() {
-        scoped_test(FeatureFlag::qmark_noglob, true, || {
+        scoped_test(FeatureFlag::QuestionMarkNoGlob, true, || {
             validate!(["string", "match", "a*b?c", "axxb?c"], STATUS_CMD_OK, "axxb?c\n");
             validate!(["string", "match", "*?", "a"], STATUS_CMD_ERROR, "");
             validate!(["string", "match", "*?", "ab"], STATUS_CMD_ERROR, "");
@@ -514,7 +514,7 @@ mod tests {
     #[serial]
     #[rustfmt::skip]
     fn test_qmark_glob() {
-        scoped_test(FeatureFlag::qmark_noglob, false, || {
+        scoped_test(FeatureFlag::QuestionMarkNoGlob, false, || {
             validate!(["string", "match", "a*b?c", "axxbyc"], STATUS_CMD_OK, "axxbyc\n");
             validate!(["string", "match", "*?", "a"], STATUS_CMD_OK, "a\n");
             validate!(["string", "match", "*?", "ab"], STATUS_CMD_OK, "ab\n");
