@@ -9,8 +9,8 @@ use crate::builtins::shared::{
 };
 use crate::common::{
     EXPAND_RESERVED_BASE, EXPAND_RESERVED_END, EscapeFlags, EscapeStringStyle, UnescapeFlags,
-    UnescapeStringStyle, char_offset, charptr2wcstring, escape, escape_string,
-    escape_string_for_double_quotes, unescape_string, valid_var_name_char, wcs2zstring,
+    UnescapeStringStyle, charptr2wcstring, escape, escape_string, escape_string_for_double_quotes,
+    unescape_string, valid_var_name_char, wcs2zstring,
 };
 use crate::complete::{CompleteFlags, Completion, CompletionList, CompletionReceiver};
 use crate::env::{EnvVar, Environment};
@@ -23,13 +23,14 @@ use crate::parse_util::{
     MaybeParentheses, parse_util_expand_variable_error, parse_util_locate_cmdsubst_range,
 };
 use crate::path::path_apply_working_directory;
+use crate::prelude::*;
 use crate::util::wcsfilecmp_glob;
-use crate::wchar::prelude::*;
 use crate::wcstringutil::{join_strings, trim};
 use crate::wildcard::{ANY_CHAR, ANY_STRING, ANY_STRING_RECURSIVE, WildcardResult};
 use crate::wildcard::{wildcard_expand_string, wildcard_has_internal};
 use crate::wutil::{Options, normalize_path, wcstoi_partial};
 use bitflags::bitflags;
+use fish_common::char_offset;
 use std::mem::MaybeUninit;
 
 bitflags! {
@@ -153,8 +154,7 @@ pub fn expand_string(
     ctx: &OperationContext,
     errors: Option<&mut ParseErrorList>,
 ) -> ExpandResult {
-    let mut completions = vec![];
-    std::mem::swap(&mut completions, out_completions);
+    let completions = std::mem::take(out_completions);
     let mut recv = CompletionReceiver::from_list(completions, ctx.expansion_limit);
     let result = expand_to_receiver(input, &mut recv, flags, ctx, errors);
     *out_completions = recv.take();
@@ -187,18 +187,17 @@ pub fn expand_one(
     ctx: &OperationContext,
     errors: Option<&mut ParseErrorList>,
 ) -> bool {
-    let mut completions = CompletionList::new();
-
     if !flags.contains(ExpandFlags::FOR_COMPLETIONS) && expand_is_clean(s) {
         return true;
     }
 
-    let mut tmp = WString::new();
-    std::mem::swap(s, &mut tmp);
-    if expand_string(tmp, &mut completions, flags, ctx, errors) == ExpandResultCode::ok
-        && completions.len() == 1
-    {
-        std::mem::swap(s, &mut completions[0].completion);
+    let mut completions = CompletionList::new();
+    let input = std::mem::take(s);
+
+    let ok = expand_string(input, &mut completions, flags, ctx, errors) == ExpandResultCode::ok;
+
+    if ok && completions.len() == 1 {
+        *s = std::mem::take(&mut completions[0].completion);
         return true;
     }
 
@@ -257,7 +256,7 @@ pub fn expand_escape_variable(var: &EnvVar) -> WString {
     let lst = var.as_list();
     for el in lst {
         if !buff.is_empty() {
-            buff.push_str("  ");
+            buff.push_str(" ");
         }
 
         // We want to use quotes if we have more than one string, or the string contains a space.
@@ -360,7 +359,7 @@ macro_rules! append_syntax_error {
             let mut error = ParseError::default();
             error.source_start = $source_start;
             error.source_length = 0;
-            error.code = ParseErrorCode::syntax;
+            error.code = ParseErrorCode::Syntax;
             error.text = wgettext_fmt!($fmt $(, $arg)*);
             errors.push(error);
         }
@@ -390,7 +389,7 @@ macro_rules! append_cmdsub_error_formatted {
             let mut error = ParseError::default();
             error.source_start = $source_start;
             error.source_length = $source_end - $source_start + 1;
-            error.code = ParseErrorCode::cmdsubst;
+            error.code = ParseErrorCode::CmdSubst;
             error.text = $text;
             if !errors.iter().any(|e| e.text == error.text) {
                 errors.push(error);
@@ -408,7 +407,7 @@ fn append_overflow_error(
         errors.push(ParseError {
             source_start: source_start.unwrap_or(SOURCE_LOCATION_UNKNOWN),
             source_length: 0,
-            code: ParseErrorCode::generic,
+            code: ParseErrorCode::Generic,
             text: wgettext!("Expansion produced too many results").to_owned(),
         });
     }
@@ -1331,14 +1330,12 @@ impl<'a, 'b, 'c> Expander<'a, 'b, 'c> {
         if self.flags.contains(ExpandFlags::FAIL_ON_CMDSUBST) {
             let mut cursor = 0;
             match parse_util_locate_cmdsubst_range(&input, &mut cursor, true, None, None) {
-                MaybeParentheses::Error => {
-                    return ExpandResult::make_error(STATUS_EXPAND_ERROR);
-                }
+                MaybeParentheses::Error => ExpandResult::make_error(STATUS_EXPAND_ERROR),
                 MaybeParentheses::None => {
                     if !out.add(input) {
                         return append_overflow_error(self.errors, None);
                     }
-                    return ExpandResult::ok();
+                    ExpandResult::ok()
                 }
                 MaybeParentheses::CommandSubstitution(parens) => {
                     append_cmdsub_error!(
@@ -1347,7 +1344,7 @@ impl<'a, 'b, 'c> Expander<'a, 'b, 'c> {
                         parens.end() - 1,
                         "command substitutions not allowed in command position. Try var=(your-cmd) $var ..."
                     );
-                    return ExpandResult::make_error(STATUS_EXPAND_ERROR);
+                    ExpandResult::make_error(STATUS_EXPAND_ERROR)
                 }
             }
         } else {
@@ -1394,8 +1391,10 @@ impl<'a, 'b, 'c> Expander<'a, 'b, 'c> {
         mut input: WString,
         out: &mut CompletionReceiver,
     ) -> ExpandResult {
+        remove_internal_separator(&mut input, self.flags.contains(ExpandFlags::SKIP_WILDCARDS));
+
         expand_home_directory(&mut input, self.ctx.vars());
-        if !feature_test(FeatureFlag::remove_percent_self) {
+        if !feature_test(FeatureFlag::RemovePercentSelf) {
             expand_percent_self(&mut input);
         }
         if !out.add(input) {
@@ -1406,15 +1405,11 @@ impl<'a, 'b, 'c> Expander<'a, 'b, 'c> {
 
     fn stage_wildcards(
         &mut self,
-        mut path_to_expand: WString,
+        path_to_expand: WString,
         out: &mut CompletionReceiver,
     ) -> ExpandResult {
         let mut result = ExpandResult::ok();
 
-        remove_internal_separator(
-            &mut path_to_expand,
-            self.flags.contains(ExpandFlags::SKIP_WILDCARDS),
-        );
         let has_wildcard = wildcard_has_internal(&path_to_expand); // e.g. ANY_STRING
         let for_completions = self.flags.contains(ExpandFlags::FOR_COMPLETIONS);
         let skip_wildcards = self.flags.contains(ExpandFlags::SKIP_WILDCARDS);
@@ -1607,7 +1602,7 @@ mod tests {
     use crate::{
         expand::{ExpandFlags, expand_string},
         operation_context::OperationContext,
-        wchar::prelude::*,
+        prelude::*,
     };
     use std::collections::HashSet;
     use std::collections::hash_map::RandomState;
