@@ -24,7 +24,7 @@ License along with the GNU C Library; see the file COPYING.LIB.  If
 not, write to the Free Software Foundation, Inc., 675 Mass Ave,
 Cambridge, MA 02139, USA.  */
 
-use crate::wchar::prelude::*;
+use crate::prelude::*;
 
 /// Special char used with [`Ordering::ReturnInOrder`].
 pub const NON_OPTION_CHAR: char = '\x01';
@@ -567,7 +567,7 @@ impl<'opts, 'args, 'argarray> WGetopter<'opts, 'args, 'argarray> {
 #[cfg(test)]
 mod tests {
     use super::{ArgType, WGetopter, WOption, wopt};
-    use crate::wchar::prelude::*;
+    use crate::prelude::*;
     use crate::wcstringutil::join_strings;
 
     #[test]
